// -*- C++ -*-
/*!
 * @file  MyServiceConsumer.cpp
 * @brief MyService Consumer Sample component
 * $Date: 2008-01-14 07:46:42 $
 *
 * $Id: MyServiceConsumer.cpp 1661 2010-01-15 09:12:51Z kurihara $
 */

#include "MyServiceConsumer.h"
#include <rtm/CORBA_SeqUtil.h>
#include <vector>
#include <stdlib.h>
#include <coil/Async.h>
#include <functional>

// Module specification
// <rtc-template block="module_spec">
static const char* myserviceconsumer_spec[] =
  {
    "implementation_id", "MyServiceConsumer",
    "type_name",         "MyServiceConsumer",
    "description",       "MyService Consumer Sample component",
    "version",           "0.1",
    "vendor",            "AIST",
    "category",          "Generic",
    "activity_type",     "DataFlowComponent",
    "max_instance",      "10",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

MyServiceConsumer::MyServiceConsumer(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    // <rtc-template block="initializer">
    m_MyServicePort("MyService"),
    // </rtc-template>
    async_set_value(0), async_echo(0)
{
}

MyServiceConsumer::~MyServiceConsumer()
{
}


RTC::ReturnCode_t MyServiceConsumer::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  m_MyServicePort.registerConsumer("myservice0", "MyService", m_myservice0);
  
  // Set CORBA Service Ports
  addPort(m_MyServicePort);
  
  // </rtc-template>

  return RTC::RTC_OK;
}

RTC::ReturnCode_t MyServiceConsumer::onExecute(RTC::UniqueId ec_id)
{
  try
    {
      if (CORBA::is_nil(m_myservice0._ptr()))
        {
          std::cout << "[nil] object reference is not assigned." << std::endl;
        }
      else
	{
	  if (m_myservice0->_non_existent())
	    {
	      std::cout << "[inactive] provider is inactive." << std::endl;
	    }
	  else
	    {
	      std::cout << "[active] provider is active." << std::endl;
	    }
        }
    }
  catch (...)
    {
      std::cout << "Unknown exception." << std::endl;
    }
  coil::sleep(1);
  return RTC::RTC_OK;
}

extern "C"
{
 
  void MyServiceConsumerInit(RTC::Manager* manager)
  {
    coil::Properties profile(myserviceconsumer_spec);
    manager->registerFactory(profile,
                             RTC::Create<MyServiceConsumer>,
                             RTC::Delete<MyServiceConsumer>);
  }
  
};


